=== modified file 'revisionview.py'
--- revisionview.py	2008-06-24 10:34:38 +0000
+++ revisionview.py	2008-06-29 19:18:34 +0000
@@ -22,9 +22,11 @@
 import gobject
 import webbrowser
 
-from bzrlib.plugins.gtk import icon_path
 from bzrlib.osutils import format_date
 from bzrlib.util.bencode import bdecode
+from bzrlib.testament import Testament
+
+from bzrlib.plugins.gtk import icon_path
 
 try:
     from bzrlib.plugins.gtk import seahorse
@@ -220,7 +222,17 @@
                                         "This revision has not been signed.")
 
     def show_signature(self, crypttext):
-        key = seahorse.verify(crypttext)
+        (cleartext, key) = seahorse.verify(crypttext)
+
+        assert cleartext is not None
+
+        inv = self.repository.get_inventory(self.revision.revision_id)
+        expected_testament = Testament(self.revision, inv).as_short_text()
+        if expected_testament != cleartext:
+            self.signature_image.set_from_file(icon_path("sign-bad.png"))
+            self.signature_label.set_markup("<b>Signature does not match repository data</b>\n" +
+                        "The signature plaintext is different from the expected testament plaintext.")
+            return
 
         if key and key.is_available():
             if key.is_trusted():
@@ -322,8 +334,8 @@
         self._create_general()
         self._create_relations()
         # Disabled because testaments aren't verified yet:
-        # if has_seahorse:
-        #    self._create_signature()
+        if has_seahorse:
+            self._create_signature()
         self._create_file_info_view()
         self._create_bugs()
 

=== modified file 'seahorse.py'
--- seahorse.py	2008-06-20 03:33:17 +0000
+++ seahorse.py	2008-06-29 19:07:23 +0000
@@ -85,7 +85,10 @@
         if key not in keyset:
             keyset[key] = Key(key)
 
-        return keyset[key]
+        return (cleartext, keyset[key])
+
+    return (cleartext, None)
+
 
 class Key:
 

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2008-06-29 19:34:29 +0000
+++ viz/branchwin.py	2008-06-06 17:46:26 +0000
@@ -18,10 +18,9 @@
 from bzrlib.plugins.gtk.tags import AddTagDialog
 from bzrlib.plugins.gtk.preferences import PreferencesWindow
 from bzrlib.plugins.gtk.branchview import TreeView, treemodel
-
-from bzrlib.config import BranchConfig, GlobalConfig
 from bzrlib.revision import Revision, NULL_REVISION
-from bzrlib.trace import mutter
+from bzrlib.config import BranchConfig
+from bzrlib.config import GlobalConfig
 
 class BranchWindow(Window):
     """Branch window.
@@ -229,15 +228,6 @@
         branch_menu.add(gtk.MenuItem("Pu_ll Revisions"))
         branch_menu.add(gtk.MenuItem("Pu_sh Revisions"))
 
-        try:
-            from bzrlib.plugins import search
-        except ImportError:
-            mutter("Didn't find search plugin")
-        else:
-            branch_index_menuitem = gtk.MenuItem("_Index")
-            branch_index_menuitem.connect('activate', self._branch_index_cb)
-            branch_menu.add(branch_index_menuitem)
-
         help_menu = gtk.Menu()
         help_menuitem = gtk.MenuItem("_Help")
         help_menuitem.set_submenu(help_menu)
@@ -466,10 +456,6 @@
         finally:
             self.treeview.set_sensitive(True)
 
-    def _branch_index_cb(self, w):
-        from bzrlib.plugins.search import index as _mod_index
-        _mod_index.index_url(self.branch.base)
-
     def _about_dialog_cb(self, w):
         from bzrlib.plugins.gtk.about import AboutDialog
 

